pub struct XarHeader {
pub magic: u32,
pub size: u16,
pub version: u16,
pub toc_length_compressed: u64,
pub toc_length_uncompressed: u64,
pub checksum_algorithm_id: u32,
}Expand description
A XAR archive header.
The header effectively defines a table of contents, which holds information about the content of the archive.
Fields
magic: u32File magic. xar!.
size: u16Size of this header + magic.
version: u16Format version number.
toc_length_compressed: u64Size in bytes of zlib compressed table of contents.
toc_length_uncompressed: u64Size in bytes of uncompressed table of contents.
checksum_algorithm_id: u32Checksum algorithm used.